ewma.RdEstimates volatility of a return series by means of an exponentially weighted moving average.
ewma(x, lambda = 0.94)a numeric vector of asset returns
decay factor for the calculation of weights; default is 0.94
Returns a numerical vector vol that contains the computed
volatility.